==> jc-1.4.0.tar.gz: javax/transaction/TransactionRequiredException.h <==
// public class javax.transaction.TransactionRequiredException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class a2f58b3e4a6cbad6 javax_transaction_TransactionRequiredException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_javax_transaction_TransactionRequiredException_H_
#define _JC_javax_transaction_TransactionRequiredException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_TransactionRequiredException$sub_refs	_jc_javax_transaction_TransactionRequiredException$sub_refs;
typedef struct _jc_javax_transaction_TransactionRequiredException$sub_nonrefs	_jc_javax_transaction_TransactionRequiredException$sub_nonrefs;
typedef struct _jc_javax_transaction_TransactionRequiredException$refs	_jc_javax_transaction_TransactionRequiredException$refs;
typedef struct _jc_javax_transaction_TransactionRequiredException$nonrefs	_jc_javax_transaction_TransactionRequiredException$nonrefs;
typedef struct _jc_javax_transaction_TransactionRequiredException$object	_jc_javax_transaction_TransactionRequiredException$object;

typedef const struct _jc_javax_transaction_TransactionRequiredException$vmethods	_jc_javax_transaction_TransactionRequiredException$vmethods;
typedef const struct _jc_javax_transaction_TransactionRequiredException$vtable	_jc_javax_transaction_TransactionRequiredException$vtable;
typedef const struct _jc_javax_transaction_TransactionRequiredException$vtype	_jc_javax_transaction_TransactionRequiredException$vtype;

// Constructors
extern void _jc_javax_transaction_TransactionRequiredException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_TransactionRequiredException$object *);
extern void _jc_javax_transaction_TransactionRequiredException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_TransactionRequiredException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_transaction_TransactionRequiredException$vmethods {
};

// Vtable
struct _jc_javax_transaction_TransactionRequiredException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_javax_transaction_TransactionRequiredException$vmethods	javax_transaction_TransactionRequiredException;
};

// Vtype
struct _jc_javax_transaction_TransactionRequiredException$vtype {
	_jc_type			type;
	_jc_javax_transaction_TransactionRequiredException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRequiredException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_TransactionRequiredException$refs {
    _jc_javax_transaction_TransactionRequiredException$sub_refs	javax_transaction_TransactionRequiredException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRequiredException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_TransactionRequiredException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_javax_transaction_TransactionRequiredException$sub_nonrefs	javax_transaction_TransactionRequiredException;
};

// Object instance structure
struct _jc_javax_transaction_TransactionRequiredException$object {
	_jc_javax_transaction_TransactionRequiredException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_TransactionRequiredException$vtype	*vtype;
	_jc_javax_transaction_TransactionRequiredException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_TransactionRequiredException$vtype _jc_javax_transaction_TransactionRequiredException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_TransactionRequiredException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_TransactionRequiredException$class_object;

#endif	/* _JC_javax_transaction_TransactionRequiredException_H_ */

==> jc-1.4.6.tar.gz: javax/transaction/TransactionRequiredException.h <==
// public class javax.transaction.TransactionRequiredException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class a2f58b3e4a6cbad6 javax_transaction_TransactionRequiredException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_javax_transaction_TransactionRequiredException_H_
#define _JC_javax_transaction_TransactionRequiredException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_transaction_TransactionRequiredException$sub_refs	_jc_javax_transaction_TransactionRequiredException$sub_refs;
typedef struct _jc_javax_transaction_TransactionRequiredException$sub_nonrefs	_jc_javax_transaction_TransactionRequiredException$sub_nonrefs;
typedef struct _jc_javax_transaction_TransactionRequiredException$refs	_jc_javax_transaction_TransactionRequiredException$refs;
typedef struct _jc_javax_transaction_TransactionRequiredException$nonrefs	_jc_javax_transaction_TransactionRequiredException$nonrefs;
typedef struct _jc_javax_transaction_TransactionRequiredException$object	_jc_javax_transaction_TransactionRequiredException$object;

typedef const struct _jc_javax_transaction_TransactionRequiredException$vmethods	_jc_javax_transaction_TransactionRequiredException$vmethods;
typedef const struct _jc_javax_transaction_TransactionRequiredException$vtable	_jc_javax_transaction_TransactionRequiredException$vtable;
typedef const struct _jc_javax_transaction_TransactionRequiredException$vtype	_jc_javax_transaction_TransactionRequiredException$vtype;

// Constructors
extern void _jc_javax_transaction_TransactionRequiredException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_transaction_TransactionRequiredException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_transaction_TransactionRequiredException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_transaction_TransactionRequiredException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_transaction_TransactionRequiredException$vmethods {
};

// Vtable
struct _jc_javax_transaction_TransactionRequiredException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_javax_transaction_TransactionRequiredException$vmethods	javax_transaction_TransactionRequiredException;
};

// Vtype
struct _jc_javax_transaction_TransactionRequiredException$vtype {
	_jc_type			type;
	_jc_javax_transaction_TransactionRequiredException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRequiredException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_transaction_TransactionRequiredException$refs {
    _jc_javax_transaction_TransactionRequiredException$sub_refs	javax_transaction_TransactionRequiredException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_transaction_TransactionRequiredException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_transaction_TransactionRequiredException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_javax_transaction_TransactionRequiredException$sub_nonrefs	javax_transaction_TransactionRequiredException;
};

// Object instance structure
struct _jc_javax_transaction_TransactionRequiredException$object {
	_jc_javax_transaction_TransactionRequiredException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_transaction_TransactionRequiredException$vtype	*vtype;
	_jc_javax_transaction_TransactionRequiredException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_transaction_TransactionRequiredException$vtype _jc_javax_transaction_TransactionRequiredException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_transaction_TransactionRequiredException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_transaction_TransactionRequiredException$class_object;

#endif	/* _JC_javax_transaction_TransactionRequiredException_H_ */
